Object.defineProperty(exports, "__esModule", { value: true });
exports.respondToBlockedUa = void 0;
const _1 = require("./");
const defaultMessage = {
    message: 'Nothing to see here - move along please...',
};
/**
 * Responds to a blocked user agent, either with the default message, or an optional custom message
 * @param {Response} res the response object
 * @param {Options} [options] will respond with a custom {@link Options#html} or {@link Options#text} message, if set
 */
const respondToBlockedUa = (res, options = { html: '', text: '' }) => {
    const log = _1.getLogger('euab:respondToBlockedUa', options);
    if (options.html || options.text) {
        log(`responding to request with ${options.html ? 'html' : 'text'}: ${options.html || options.text}`);
        res.status(200).send(options.html || options.text);
        return;
    }
    log(`responding to request with default message: ${JSON.stringify(defaultMessage)}`);
    res.status(200).json(defaultMessage);
};
exports.respondToBlockedUa = respondToBlockedUa;
